# Table of Contents

- [relations-between-applications-and-hardware-software-items](<./relations-between-applications-and-hardware-software-items.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Relations Between Applications and Hardware/Software Items](<./Relations-Between-Applications-and-HardwareSoftware-Items.md>)
  - [Overview](<./Relations-Between-Applications-and-HardwareSoftware-Items/Overview.md>)
  - [Relation Types](<./Relations-Between-Applications-and-HardwareSoftware-Items/Relation-Types.md>)
  - [Configuring Relation Mapping](<./Relations-Between-Applications-and-HardwareSoftware-Items/Configuring-Relation-Mapping.md>)
